@@ -72,7 +72,7 @@ C
       COMMON /GEOKST/ NATOMS,LABELS(NUMATM), NABC(3*NUMATM)
 C
       COMMON /ABC/    CO(3,NUMATM),IAN(NUMATM),NATOM
-      COMMON /WORK1/    POTPT(3,MESP), WORK1D(4*MESP)
+      COMMON /WORK1/  POTPT(3,MESP),WORK1D(4*MESP)
       COMMON /POTESP/ XC,YC,ZC,ESPNUC,ESPELE,NESP
 C
       DATA VDERW/53*0.0D0/
@@ -204,8 +204,7 @@ C***********************************************************************
       COMMON /KEYWRD/ KEYWRD
 C
       COMMON /ABC/    CO(3,NUMATM),IAN(NUMATM),NATOM
-      COMMON /WORK1/    POTPT(3,MESP), PAD1(2*MESP), RAD(MESP),
-     1IAS(MESP)
+      COMMON /WORK1/  POTPT(3,MESP),PAD1(2*MESP),RAD(MESP),IAS(MESP)
       COMMON /POTESP/ XC,YC,ZC,ESPNUC,ESPELE,NESP
 C
       CHARACTER*241 KEYWRD
@@ -945,7 +944,7 @@ C     UNIT 21
 C
       POTWRT=(INDEX(KEYWRD,'POTWRT') .NE. 0)
       IF(POTWRT) THEN
-         OPEN(21,STATUS='NEW')
+         OPEN(UNIT=21)
          WRITE(21,'(I5)') NESP
          DO 410 I=1,NESP
   410    WRITE(21,420) ESP(I),POTPT(1,I)/BOHR,POTPT(2,I)/BOHR,
@@ -2354,7 +2353,7 @@ C     UNIT 21
 C
       POTWRT=(INDEX(KEYWRD,'POTWRT') .NE. 0)
       IF(POTWRT) THEN
-         OPEN(21,STATUS='NEW')
+         OPEN(UNIT=21)
          WRITE(21,'(I5)') NESP
          DO 410 I=1,NESP
   410    WRITE(21,420) ESP(I),POTPT(1,I)/BOHR,POTPT(2,I)/BOHR,
