@@ -16,7 +16,8 @@ LAST MODIFIACTION
      June 21, 1995, Istvan Cserny (cserny@atomki.hu)
 */
 
-#include "f2c.h" 
+#include "mopac7f2c.h"
+
 #include <time.h>
 #include <string.h>
 
