@@ -505,8 +505,8 @@ C     DEBUG PRINT.
   220 FORMAT(1H1,//1X,'AO INTEGRALS IN NEW ORDER.'/)
   230 FORMAT(//1X,'THE AO INTEGRALS ARE STORED IN A MATRIX WITH',I4,
      1  ' ROWS AND COLUMNS.')
-  240 FORMAT(  1X,'THERE ARE',I4,' RECORDS EACH OF WHICH CONTAINS',I4/2X
-     1  ' COLUMNS AND',I6,' INTEGRALS.')
+  240 FORMAT(  1X,'THERE ARE',I4,' RECORDS EACH OF WHICH ',
+     1  'CONTAINS',I4/2X,' COLUMNS AND',I6,' INTEGRALS.')
   250 FORMAT(//1X,'INTEGRALS IN THE FIRST RECORD.'/)
   260 FORMAT(  1X,10F7.3)
       END
