@@ -74,6 +74,7 @@ C***************************************************************
       CHARACTER*4  IFRA, NAME, ISTA, NAMO, NIMM
       COMMON /SYMINF/ IBASE(2,12),NBASE,IVIBRO(2,12),IVIB
       DATA IFRA / '????'  /
+      WRITE(6,'('' == symtrz.f SYMAN1 =='')')
       IF(NUM1.LT.2) GOTO 12
       IF(NUM2.LT.2) GOTO 12
       IF(NUM1.GT.MXDIM) GOTO 12
@@ -114,6 +115,7 @@ C
       CHARACTER*4  IFRA, NAME, ISTA, NAMO, NIMM
       COMMON /SYMINF/ IBASE(2,12),NBASE,IVIBRO(2,12),IVIB
       DATA IFRA / '????'  /
+      WRITE(6,'('' == symtrz.f SYMAN2 =='')')
       IF(NUM1.LT.2) GOTO 12
       IF(NUM2.LT.2) GOTO 12
       IF(NUM1.GT.MXDIM) GOTO 12
@@ -177,6 +179,7 @@ C
       DIMENSION RHELP(3,3)
       DIMENSION ICYC(6)
       DATA TOLER,BIG/ 0.1D0,1.D35 /
+      WRITE(6,'('' == symtrz.f R00001 =='')')
       DO 2 I=1,3
       DO 1 J=1,3
  1    CUB(I,J)=0.D0
@@ -338,6 +341,7 @@ C
       COMMON /S00002/ NUMAT,NORBS,NADIM,NCDIM,IQUAL,NDORBS,IERROR
       COMMON /S00004/ SHIFT(3),R(3,3),VECT(2,MXDIM)
       DIMENSION COORD(3,NUMATM)
+      WRITE(6,'('' == symtrz.f R00002 =='')')
       CALL R00005(COORD,-1)
       DO 1 K=1,3
       BUFF=-SINA*R(K,I)+COSA*R(K,J)
@@ -359,6 +363,7 @@ C
       DIMENSION COORD(3,NUMATM),NAT(NUMATM),WINK(2)
       DATA BIG,TOLER / 1.D35,0.1/
       DATA WINK(1),WINK(2)/ 0.955316618125D0, 0.6523581398D0        /
+      WRITE(6,'('' == symtrz.f R00003 =='')')
       GOTO (1,5),JUMP
  1    IELEM(19)=1
       INDEX=0
@@ -441,6 +446,7 @@ C
       INCLUDE 'SIZES'
       COMMON /S00003/ IELEM(20),ELEM(3,3,20),CUB(3,3),JELEM(20,NUMATM)
       DIMENSION HELP(3,3),FMAT(3,3)
+      WRITE(6,'('' == symtrz.f R00004 =='')')
       DO 1 I=1,3
       DO 1 J=1,3
       HELP(I,J)=0.D0
@@ -462,6 +468,7 @@ C
       COMMON /S00002/ NUMAT,NORBS,NADIM,NCDIM,IQUAL,NDORBS,IERROR
       COMMON /S00004/ SHIFT(3),R(3,3),VECT(2,MXDIM)
       DIMENSION COORD(3,NUMATM),HELP(3)
+      WRITE(6,'('' == symtrz.f R00005 =='')')
       IF(JUMP.LT.0) GOTO 3
       DO 2 I=1,NUMAT
       DO 1 J=1,3
@@ -509,6 +516,7 @@ C
       DATA J(1,19),J(2,19),J(3,19) /       5   ,    0   ,   -1     /
       DATA J(1,20),J(2,20),J(3,20) /       0   ,    0   ,   -1     /
       DATA TWOPI / 6.283185308D0 /
+      WRITE(6,'('' == symtrz.f R00006 =='')')
       DO 2 I=1,3
       DO 1 K=1,3
  1    ELEM(I,K,IPLACE)=0.
@@ -536,6 +544,7 @@ C
       COMMON /S00002/ NUMAT,NORBS,NADIM,NCDIM,IQUAL,NDORBS,IERROR
       COMMON /S00003/ IELEM(20),ELEM(3,3,20),CUB(3,3),JELEM(20,NUMATM)
       DATA TOLER / 0.01 D0/
+      WRITE(6,'('' == symtrz.f R00007 =='')')
       IRESUL=1
       IQUAL=0
       DO 2 I=1,NUMAT
@@ -618,8 +627,8 @@ C
      .4HA     ,                  0                                     /
       DATA CS
      ./                         2HCS,
-     .4HA'    ,          8      ,      20104                           ,
-     .4HA"    ,          1      ,       -1                             /
+     .4HA     ,          8      ,      20104                           ,
+     .4HA     ,          1      ,       -1                             /
       DATA CI
      ./                         2HCI,
      .4HAG    ,         64      ,      10107                           ,
@@ -650,7 +659,7 @@ C
      .2HE2 ,   2    ,   -1    ,   -1    ,    2    ,   -1    ,   -1     /
       DATA C7
      ./                         2HC7,
-     .2HA ,2048,7140112,7240122,7340123,7440124,7540125,7640126,
+     .2HA  ,2048,7140112,7240122,7340123,7440124,7540125,7640126,
      .2HE1 ,   2   ,  71   ,  72   ,  73    ,  73   ,  72   ,  71    ,
      .2HE2 ,   2   ,  72   ,  73   ,  71    ,  71   ,  73   ,  72    ,
      .2HE3 ,   2   ,  73   ,  71   ,  72    ,  72   ,  71   ,  73    /
@@ -733,13 +742,13 @@ C
      .4HBU    ,      1    ,   -1    ,   -1    ,    1                   /
       DATA C3H
      ./                         3HC3H,
-     .2HA' ,  136   ,  3140108,  3240122,    20104,  3130124,3530143   ,
-     .2HE' ,   2    ,   -1    ,   -1    ,    2    ,   -1    ,   -1     ,
-     .2HA" ,   1    ,    1    ,    1    ,   -1    ,   -1    ,   -1     ,
-     .2HE" ,   2    ,   -1    ,   -1    ,   -2    ,    1    ,    1     /
+     .2HA  ,  136   ,  3140108,  3240122,    20104,  3130124,3530143   ,
+     .2HE  ,   2    ,   -1    ,   -1    ,    2    ,   -1    ,   -1     ,
+     .2HA  ,   1    ,    1    ,    1    ,   -1    ,   -1    ,   -1     ,
+     .2HE  ,   2    ,   -1    ,   -1    ,   -2    ,    1    ,    1     /
       DATA C4H
      ./                         3HC4H,
-     .2HAG,8524,4140109,2140103,4340123,10107,4330152,20104,4130114,
+     .2HAG ,8524,4140109,2140103,4340123,10107,4330152,20104,4130114,
      .2HBG ,   1  ,  -1  ,   1  ,  -1  ,   1  ,  -1  ,   1  ,  -1      ,
      .2HEG ,   2  ,   0  ,  -2  ,   0  ,   2  ,   0  ,  -2  ,   0      ,
      .2HAU ,   1  ,   1  ,   1  ,   1  ,  -1  ,  -1  ,  -1  ,  -1      ,
@@ -747,16 +756,16 @@ C
      .2HEU ,   2  ,   0  ,  -2  ,   0  ,  -2  ,   0  ,   2  ,   0      /
       DATA C5H
      ./                         3HC5H,
-     .2HA',520,5140110,5240122,5340123,5440124,20104,5130119,5730163,
+     .2HA   ,520,5140110,5240122,5340123,5440124,20104,5130119,5730163,
      .                                               5330164,5930165,
-     .3HE1' ,  2  , 51  , 52  ,52  , 51  ,  2  , 51  , 52  , 52  , 51  ,
-     .3HE2' ,  2  , 52  , 51  ,51  , 52  ,  2  , 52  , 51  , 51  , 52  ,
-     .2HA"  ,  1  ,  1  ,  1  , 1  ,  1  , -1  , -1  , -1  , -1  , -1  ,
-     .3HE1" ,  2  , 51  , 52  ,52  , 51  , -2  ,103  ,101  ,101  ,103  ,
-     .3HE2" ,  2  , 52  , 51  ,51  , 52  , -2  ,101  ,103  ,103  ,101  /
+     .3HE1  ,  2  , 51  , 52  ,52  , 51  ,  2  , 51  , 52  , 52  , 51  ,
+     .3HE2  ,  2  , 52  , 51  ,51  , 52  ,  2  , 52  , 51  , 51  , 52  ,
+     .2HA   ,  1  ,  1  ,  1  , 1  ,  1  , -1  , -1  , -1  , -1  , -1  ,
+     .3HE1  ,  2  , 51  , 52  ,52  , 51  , -2  ,103  ,101  ,101  ,103  ,
+     .3HE2  ,  2  , 52  , 51  ,51  , 52  , -2  ,101  ,103  ,103  ,101  /
       DATA C6H
      ./                         3HC6H,
-     .2HAG,17612,6140111,3140108,2140103,3240133,6540125,10107,20104,
+     .2HAG ,17612,6140111,3140108,2140103,3240133,6540125,10107,20104,
      .                                  3530127,6530137,6130115,3130183,
      .3HBG ,  1 , -1 ,  1 , -1 ,  1 , -1 ,  1 , -1 , -1 ,  1 ,  1 , -1 ,
      .3HE1G,  2 ,  1 , -1 , -2 , -1 ,  1 ,  2 , -2 ,  1 , -1 , -1 ,  1 ,
@@ -777,15 +786,15 @@ C
      .3HB3U,   1   ,  -1   ,  -1   ,   1   ,  -1   ,   1   ,   1   , -1/
       DATA D3H
      ./                         3HD3H,
-     .3HA1',  153  ,3140208   ,2140301  , 20104  ,3130224   , 20305    ,
-     .3HA2',   1    ,    1    ,   -1    ,    1    ,    1    ,   -1     ,
-     .3HE' ,   2    ,   -1    ,    0    ,    2    ,   -1    ,    0     ,
-     .3HA1",   1    ,    1    ,    1    ,   -1    ,   -1    ,   -1     ,
-     .3HA2",   1    ,    1    ,   -1    ,   -1    ,   -1    ,    1     ,
-     .3HE" ,   2    ,   -1    ,    0    ,   -2    ,    1    ,    0     /
+     .3HA1 ,  153  ,3140208   ,2140301  , 20104  ,3130224   , 20305    ,
+     .3HA2 ,   1    ,    1    ,   -1    ,    1    ,    1    ,   -1     ,
+     .3HE  ,   2    ,   -1    ,    0    ,    2    ,   -1    ,    0     ,
+     .3HA1 ,   1    ,    1    ,    1    ,   -1    ,   -1    ,   -1     ,
+     .3HA2 ,   1    ,    1    ,   -1    ,   -1    ,   -1    ,    1     ,
+     .3HE  ,   2    ,   -1    ,    0    ,   -2    ,    1    ,    0     /
       DATA D4H
      ./                         3HD4H,
-     .3HA1G,8575,4140209,2140103,2140201,2140220,10107,4130214,20104,
+     .3HA1G ,8575,4140209,2140103,2140201,2140220,10107,4130214,20104,
      .                                                      20205,20229,
      .3HA2G ,  1 ,  1 ,  1 , -1 , -1 ,  1 ,  1 ,  1 , -1 , -1 ,
      .3HB1G ,  1 , -1 ,  1 ,  1 , -1 ,  1 , -1 ,  1 ,  1 , -1 ,
@@ -798,17 +807,17 @@ C
      .3HEU  ,  2 ,  0 , -2 ,  0 ,  0 , -2 ,  0 ,  2 ,  0 ,  0 /
       DATA D5H
      ./                         3HD5H,
-     .3HA1',537, 5140210, 5240222,2140501,20104,5130219,  5330263,20505,
-     .3HA2',  1  ,  1   ,    1   , -1  ,   1  ,   1    ,    1    , -1  ,
-     .3HE1',  2  , 51   ,   52   ,  0  ,   2  ,  51    ,   52    ,  0  ,
-     .3HE2',  2  , 52   ,   51   ,  0  ,   2  ,  52    ,   51    ,  0  ,
-     .3HA1",  1  ,  1   ,    1   ,  1  ,  -1  ,  -1    ,   -1    , -1  ,
-     .3HA2",  1  ,  1   ,    1   , -1  ,  -1  ,  -1    ,   -1    ,  1  ,
-     .3HE1",  2  , 51   ,   52   ,  0  ,  -2  , 103    ,  101    ,  0  ,
-     .3HE2",  2  , 52   ,   51   ,  0  ,  -2  , 101    ,  103    ,  0  /
+     .3HA1  ,537, 5140210, 5240222,2140501,20104,5130219, 5330263,20505,
+     .3HA2  ,  1  ,  1   ,    1   , -1  ,   1  ,   1   ,    1    , -1  ,
+     .3HE1  ,  2  , 51   ,   52   ,  0  ,   2  ,  51   ,   52    ,  0  ,
+     .3HE2  ,  2  , 52   ,   51   ,  0  ,   2  ,  52   ,   51    ,  0  ,
+     .3HA1  ,  1  ,  1   ,    1   ,  1  ,  -1  ,  -1   ,   -1    , -1  ,
+     .3HA2  ,  1  ,  1   ,    1   , -1  ,  -1  ,  -1   ,   -1    ,  1  ,
+     .3HE1  ,  2  , 51   ,   52   ,  0  ,  -2  , 103   ,  101    ,  0  ,
+     .3HE2  ,  2  , 52   ,   51   ,  0  ,  -2  , 101   ,  103    ,  0  /
       DATA D6H
      ./                         3HD6H,
-     .3HA1G,17663,6140211,3140208,2140103,2140301,2140302,10107,20104,
+     .3HA1G ,17663,6140211,3140208,2140103,2140301,2140302,10107,20104,
      .                                      6130215,3130238,20306,20305,
      .3HA2G ,   1,  1,  1,  1, -1, -1,  1,  1,  1,  1, -1, -1,
      .3HB1G ,   1, -1,  1, -1,  1, -1,  1, -1,  1, -1,  1, -1,
@@ -847,8 +856,8 @@ C
      .3HE3  , 2 ,    83     ,  0 ,    81     , -2 ,  0 ,  0 /
       DATA D5D
      ./                         3HD5D,
-     .3HA1G,66130,5140210,5240222,2140502,10107,10130217,
-     .                                                  10330226,20505,
+     .3HA1G ,66130,5140210,5240222,2140502,10107,10130217,
+     .                                                10330226,20505,
      .3HA2G ,   1  ,   1  ,   1  ,  -1  ,   1  ,   1  ,   1  ,  -1  ,
      .3HE1G ,   2  ,  51  ,  52  ,   0  ,   2  ,  52  ,  51  ,   0  ,
      .3HE2G ,   2  ,  52  ,  51  ,   0  ,   2  ,  51  ,  52  ,   0  ,
@@ -858,8 +867,8 @@ C
      .3HE2U ,   2  ,  52  ,  51  ,   0  ,  -2  , 103  , 101  ,   0  /
       DATA D6D
      ./                         3HD6D,
-     .2HA1,140468,12130218,6140211,4130214,3140208,12530225,2140103,
-     .                                                    20605,2140620,
+     .2HA1  ,140468,12130218,6140211,4130214,3140208,12530225,2140103,
+     .                                                  20605,2140620,
      .3HA2  , 1 ,    1  , 1 , 1 , 1 ,   1  , 1 ,-1 ,-1 ,
      .3HB1  , 1 ,   -1  , 1 ,-1 , 1 ,  -1  , 1 ,-1 , 1 ,
      .3HB2  , 1 ,   -1  , 1 ,-1 , 1 ,  -1  , 1 , 1 ,-1 ,
@@ -896,7 +905,7 @@ C
      .2HT2 ,     3    ,     0    ,    -1     ,   -1      ,   1         /
       DATA OH
      ./                         3HOH ,
-     .3HA1G,287231,3140808,2140601,4140609,2140303,10107,4130614,
+     .3HA1G ,287231,3140808,2140601,4140609,2140303,10107,4130614,
      .                                              6130815,20304,20605,
      .3HA2G ,  1 ,  1 , -1 , -1 ,  1 ,  1 , -1 ,  1 ,  1 , -1 ,
      .3HEG  ,  2 , -1 ,  0 ,  0 ,  2 ,  2 ,  0 , -1 ,  2 ,  0 ,
@@ -933,6 +942,7 @@ C
      .3HSIU ,         1        ,         1        ,        -1          ,
      .3HPIU ,         2        ,         0        ,        -2          ,
      .3HDEU ,         2        ,        -2        ,        -2          /
+      WRITE(6,'('' == symtrz.f R00008 =='')')
       SIG=1.D0
       I=IGROUP
       IF(NCODE.LT.0) GOTO 2
@@ -993,6 +1003,7 @@ C
       COMMON /S00003/ IELEM(20),ELEM(3,3,20),CUB(3,3),JELEM(20,NUMATM)
       COMMON /S00004/ SHIFT(3),R(3,3),VECT(2,MXDIM)
       DIMENSION HELP(3,3),NAT(NUMATM),COORD(3,NUMATM)
+      WRITE(6,'('' == symtrz.f R00009 =='')')
       DO 1 I=1,3
       DO 1 J=1,NUMAT
  1    COORD(I,J)=COORD(I,J)-SHIFT(I)
@@ -1034,7 +1045,9 @@ C
       IMPLICIT DOUBLE PRECISION (A-H,O-Z)
       INCLUDE 'SIZES'
       PARAMETER (MXDIM=MAXPAR+NUMATM)
-      CHARACTER*4  NAME,ISTA
+C     CHARACTER*4 NAME,ISTA
+C ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ ; NAME is not used...
+      CHARACTER*4 ISTA
       COMMON /S00001/         T(12,12),JX(7,12),LINA,I1,J1,J2
       COMMON /S00002/ NUMAT,NORBS,NADIM,NCDIM,IQUAL,NDORBS,IERROR
       COMMON /S00003/ IELEM(20),ELEM(3,3,20),CUB(3,3),JELEM(20,NUMATM)
@@ -1042,8 +1055,12 @@ C
       COMMON/SYMRES/TRANS,RTR,SIG,NAME,NAMO(MXDIM),INDEX(MXDIM),ISTA(2)
       DIMENSION NTYPE(MXDIM),COEFF(NCDUM,NCDUM)
       DIMENSION CHAR(12),ICOUNT(12)
-      DATA TOLER,IFRA /  0.1, '????'/
+C     DATA TOLER,IFRA /  0.1, '????'/
+C ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
+      INTEGER NAMES
+      DATA TOLER,IFRA / 0.1, 0 /
 C
+      WRITE(6,'('' == symtrz.f R00010 =='')')
       NDORBS=0
       DO 1 I=1,I1
  1    ICOUNT(I)=0
@@ -1094,6 +1111,7 @@ C
       DIMENSION NTYPE(MXDIM),COEFF(NCDUM,NCDUM),E(3,3,20)
       DIMENSION H(5),P(3),D(5),IP(2,3),ID(2,5),LOC(2,50)
       EQUIVALENCE (ELEM(1,1,1),E(1,1,1))
+      WRITE(6,'('' == symtrz.f R00011 =='')')
       R00011=1.D0
       IF(IOPER.EQ.1) RETURN
       DO 1 I=1,NORBS
@@ -1205,6 +1223,7 @@ C
       COMMON /S00004/ SHIFT(3),R(3,3),VECT(2,MXDIM)
       DIMENSION D(5),H(5),T1(5,5,12),S(3,3)
       CHARACTER JX*4
+      WRITE(6,'('' == symtrz.f R00012 =='')')
       IF(NDORBS.GT.0) GOTO 4
       NDORBS=1
       DO 1 I=1,3
@@ -1236,6 +1255,7 @@ C
       LOGICAL RIGHT
       DATA PI,TOL,S12 / 3.1415926536D0 ,0.001D0,3.46410161513D0 /
       DATA S3,ONE     / 1.73205080756D0 , 1.D0 /
+      WRITE(6,'('' == symtrz.f R00013 =='')')
       R1=R(2,1)*R(3,2)-R(3,1)*R(2,2)
       R2=R(3,1)*R(1,2)-R(1,1)*R(3,2)
       R3=R(1,1)*R(2,2)-R(2,1)*R(1,2)
@@ -1329,6 +1349,7 @@ C
       IMPLICIT DOUBLE PRECISION (A-H,O-Z)
       DIMENSION F(6),A(3,3),V(3,3),EW(3)
       DATA TOLER /1.E-6 /
+      WRITE(6,'('' == symtrz.f R00015 =='')')
       N=3
       IJ=0
       DO 2 J=1,N
@@ -1427,6 +1448,7 @@ C
       COMMON /SYMINF/ IBASE(2,12),NBASE,IVIBRO(2,12),IVIB
       COMMON/SYMRES/TRANS,RTR,SIG,NAME,NAMO(MXDIM),INDEX(MXDIM),ISTA(2)
       DIMENSION CHAR(12),COEFF(12)
+      WRITE(6,'('' == symtrz.f R00016 =='')')
       IVIBRA=3*NUMAT-6
       IF(LINA.GT.0) GOTO 8
       CHAR(1)=IVIBRA
